==> lxqt-panel_0.14.1.orig.tar.xz: lxqt-panel-0.14.1/plugin-spacer/translations/spacer_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Налаштування розділювача</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Ширина розділювача:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="40"/>
        <source>Space type:</source>
        <translation>Тип розділювача:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="57"/>
        <source>fixed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="71"/>
        <source>expandable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>лінійований</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>пунктирний</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>невидимий</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.2.2.orig.tar.xz: lxqt-panel-2.2.2/plugin-spacer/translations/spacer_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>SpacerConfiguration</name>
    <message>
        <location filename="../spacerconfiguration.ui" line="14"/>
        <source>Spacer Settings</source>
        <translation>Налаштування розділювача</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="20"/>
        <source>Space width:</source>
        <translation>Ширина розділювача:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="54"/>
        <source>Space type:</source>
        <translation>Тип розділювача:</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="27"/>
        <source>fixed</source>
        <translation>сталий</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.ui" line="47"/>
        <source>expandable</source>
        <translation>розтягуваний</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="34"/>
        <source>lined</source>
        <translation>лінійований</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="35"/>
        <source>dotted</source>
        <translation>пунктирний</translation>
    </message>
    <message>
        <location filename="../spacerconfiguration.cpp" line="36"/>
        <source>invisible</source>
        <translation>невидимий</translation>
    </message>
</context>
</TS>
